@@ -164,9 +164,9 @@ void recv_exclude_list(int f)
   char line[MAXPATHLEN];
   int l;
   while ((l=read_int(f))) {
-    read_buf(f,line,l);
-    line[l] = 0;
-    add_exclude(line);
+	  if (l >= MAXPATHLEN) overflow("recv_exclude_list");
+	  read_sbuf(f,line,l);
+	  add_exclude(line);
   }
 }
 
